==> oto-service-api-0.1.71-xt-20240819.062843-82-sources.jar: cn/com/duiba/oto/param/oto/goods/RemoteGenerateOrderParam.java <==
package cn.com.duiba.oto.param.oto.goods;

import lombok.Data;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Date;

/**
 * @Author huliangsheng
 * @Date 2024/8/15 18:19
 */
@Data
public class RemoteGenerateOrderParam implements Serializable {
    private static final long serialVersionUID = 1873297733997784319L;

    /**
     * 商品id
     */
    private Long id;

    /**
     * 商品规格
     */
    private String goodsStandard;

    /**
     * custId
     */
    private Long custId;
    /**
     * userId
     */
    private String userId;
    /**
     * clientIp
     */
    private String clientIp;

    /**
     * 购买数量
     */
    private Integer purchaseCount;

    /**
     * 商品原价
     */
    private Integer originalPrice;

    /**
     * 立减金
     */
    private Integer minusPrice;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getGoodsStandard() {
        return goodsStandard;
    }

    public void setGoodsStandard(String goodsStandard) {
        this.goodsStandard = goodsStandard;
    }

    public Integer getPurchaseCount() {
        return purchaseCount;
    }

    public void setPurchaseCount(Integer purchaseCount) {
        this.purchaseCount = purchaseCount;
    }

    public Integer getOriginalPrice() {
        return originalPrice;
    }

    public void setOriginalPrice(Integer originalPrice) {
        this.originalPrice = originalPrice;
    }

    public Integer getMinusPrice() {
        return minusPrice;
    }

    public void setMinusPrice(Integer minusPrice) {
        this.minusPrice = minusPrice;
    }
}

==> oto-service-api-0.3.3-xt-20251029.075735-3-sources.jar: cn/com/duiba/oto/param/oto/goods/RemoteGenerateOrderParam.java <==
package cn.com.duiba.oto.param.oto.goods;

import lombok.Data;

import java.io.Serializable;

/**
 * @Author huliangsheng
 * @Date 2024/8/15 18:19
 */
@Data
public class RemoteGenerateOrderParam implements Serializable {
    private static final long serialVersionUID = 1873297733997784319L;

    /**
     * 商品id
     */
    private Long id;

    /**
     * 商品规格
     */
    private String goodsStandard;

    /**
     * custId
     */
    private Long custId;
    /**
     * userId
     */
    private String userId;
    /**
     * clientIp
     */
    private String clientIp;

    /**
     * 购买数量
     */
    private Integer purchaseCount;

    /**
     * 商品原价
     */
    private Integer originalPrice;

    /**
     * 立减金
     */
    private Integer minusPrice;

    /**
     * 下单的appId
     */
    private String appId;

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getGoodsStandard() {
        return goodsStandard;
    }

    public void setGoodsStandard(String goodsStandard) {
        this.goodsStandard = goodsStandard;
    }

    public Integer getPurchaseCount() {
        return purchaseCount;
    }

    public void setPurchaseCount(Integer purchaseCount) {
        this.purchaseCount = purchaseCount;
    }

    public Integer getOriginalPrice() {
        return originalPrice;
    }

    public void setOriginalPrice(Integer originalPrice) {
        this.originalPrice = originalPrice;
    }

    public Integer getMinusPrice() {
        return minusPrice;
    }

    public void setMinusPrice(Integer minusPrice) {
        this.minusPrice = minusPrice;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public Long getCustId() {
        return custId;
    }

    public void setCustId(Long custId) {
        this.custId = custId;
    }

    public String getClientIp() {
        return clientIp;
    }

    public void setClientIp(String clientIp) {
        this.clientIp = clientIp;
    }
}
